==> jredmine-client-1.3-sources.jar: org/nuiton/jredmine/model/io/xpp3/IssuePriorityXpp3Reader.java <==
/*
 * #%L
 * JRedmine :: Client
 * 
 * $Id: IssuePriorityXpp3Reader.java 211 2011-06-04 17:01:31Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jredmine/tags/jredmine-1.3/jredmine-client/src/main/java/org/nuiton/jredmine/model/io/xpp3/IssuePriorityXpp3Reader.java $
 * %%
 * Copyright (C) 2009 - 2010 Tony Chemit, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.jredmine.model.io.xpp3;

import org.nuiton.io.xpp3.AbstractXpp3Reader;
import org.nuiton.jredmine.model.Issue;
import org.nuiton.jredmine.model.IssuePriority;

import java.beans.IntrospectionException;

import static org.nuiton.io.xpp3.Xpp3Helper.addTagTextContentMappers;

/**
 * {@link Issue} reader.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0.0
 */
public class IssuePriorityXpp3Reader extends AbstractXpp3Reader<IssuePriority> {

    public IssuePriorityXpp3Reader() {
        super(IssuePriority.class, "issue-priorities", "issue-priority");
    }

    @Override
    protected void initMappers() throws IntrospectionException {


        addTagTextContentMappers(IssuePriority.class, RedmineDataConverter.Integer, true, allMappers,
                                 "id",
                                 "parent-id",
                                 "project-id",
                                 "position");

        addTagTextContentMappers(IssuePriority.class, RedmineDataConverter.Boolean, true, allMappers,
                                 "is-default",
                                 "active");

        addTagTextContentMappers(IssuePriority.class, RedmineDataConverter.Text, true, allMappers,
                                 "name",
                                 "opt");
    }
}

==> jredmine-client-1.4-sources.jar: org/nuiton/jredmine/model/io/xpp3/IssuePriorityXpp3Reader.java <==
/*
 * #%L
 * JRedmine :: Client
 * 
 * $Id: IssuePriorityXpp3Reader.java 303 2012-07-15 11:14:29Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jredmine/tags/jredmine-1.4/jredmine-client/src/main/java/org/nuiton/jredmine/model/io/xpp3/IssuePriorityXpp3Reader.java $
 * %%
 * Copyright (C) 2009 - 2012 Tony Chemit, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.jredmine.model.io.xpp3;

import org.nuiton.io.xpp3.AbstractXpp3Reader;
import org.nuiton.jredmine.model.Issue;
import org.nuiton.jredmine.model.IssuePriority;

import java.beans.IntrospectionException;

/**
 * {@link Issue} reader.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0.0
 */
public class IssuePriorityXpp3Reader extends AbstractXpp3Reader<IssuePriority> {

    public IssuePriorityXpp3Reader() {
        super(IssuePriority.class, "issue-priorities", "issue-priority");
    }

    @Override
    protected void initMappers() throws IntrospectionException {


        addTagTextContentMappers(RedmineDataConverter.Integer, true, 
                                 "id",
                                 "parent-id",
                                 "project-id",
                                 "position");

        addTagTextContentMappers(RedmineDataConverter.Boolean, true, 
                                 "is-default",
                                 "active");

        addTagTextContentMappers(RedmineDataConverter.Text, true, 
                                 "name",
                                 "opt");
    }
}
